pub struct ChainedTokenCredential { /* private fields */ }Expand description
Tries a sequence of credentials in order, returning the first token
obtained. The index of the first credential to succeed is remembered and
tried first on subsequent calls (re-remembered if a different one later
wins), mirroring azure_identity’s ChainedTokenCredential.
Implementations
Sourceimpl ChainedTokenCredential
impl ChainedTokenCredential
Sourcepub fn new(credentials: Vec<Arc<dyn TokenCredential>>) -> Self
pub fn new(credentials: Vec<Arc<dyn TokenCredential>>) -> Self
Build a chain from an ordered list of credentials.